<?php

namespace Drupal\contacts\Controller;

use Drupal\contacts\Form\AddIndivForm;
use Drupal\contacts\Form\AddOrgForm;
use Drupal\Core\Controller\ControllerBase;

/**
 * Controller for adding new contacts.
 */
class AddContactController extends ControllerBase {

  /**
   * Displays the 'Add New Individual' screen.
   *
   * @return array
   *   Render array.
   */
  public function addIndividual() {
    if ($this->useLegacyForms()) {
      return $this->formBuilder()->getForm(AddIndivForm::class);
    }

    $user = $this->entityTypeManager()
      ->getStorage('user')
      ->create();

    return $this->entityFormBuilder()->getForm($user, 'add_contact_individual');
  }

  /**
   * Displays the 'Add Organisation' screen.
   *
   * @return array
   *   Render array.
   */
  public function addOrganisation() {
    if ($this->useLegacyForms()) {
      return $this->formBuilder()->getForm(AddOrgForm::class);
    }

    $user = $this->entityTypeManager()
      ->getStorage('user')
      ->create();

    return $this->entityFormBuilder()->getForm($user, 'add_contact_organisation');
  }

  /**
   * Determines whether to use the legacy or new version of Add Contacts.
   *
   * @return bool
   *   TRUE if the legacy version should be used, otherwise FALSE.
   */
  private function useLegacyForms() {
    $config = $this->config('contacts.configuration');
    $contact_form_type = $config->get('add_contact_form_type') ?? 'legacy';
    return $contact_form_type === 'legacy';
  }

}
